class BaseConfig(object):

    # the ngrok conf for get webhooks
    NGROk_ADDR = 'localhost'
    NGROK_PORT = '80'
    WEBHOOK_SECRET = 'whsec_ockkw25Bge0wgoIkXHhGb6tYZYiNoLzl'
    STRIPE_KEY_TEST = "sk_test_T7ugYRCXZwOezUViefmVlD2E"



from flask import request, Blueprint
from flask_restful import Resource, reqparse, abort
from stripe_webhook_parser.events import _plan_created, _plan_updated, _plan_deleted
from stripe_webhook_parser.events import _product_created, _product_updated, _product_deleted
from stripe_webhook_parser.events import _customer_subscription_created, _customer_subscription_deleted
from stripe_webhook_parser.events import _invoice_payment_succeed
from stripe_webhook_parser.events import _charge_succeeded
from stripe_webhook_parser.events import _customer_created, _customer_updated, _customer_deleted
from nowhat.tasks.tasks import asyncc
import stripe
import os
import json


webhook_secret = os.environ.get('WEBHOOK_SECRET')
webhook = Blueprint('webhook', __name__)
stripe.api_key = "STRIPE_KEY_TEST"


class MyWebhooks(object):

    @staticmethod
    @webhook.route('/webhooks', methods=['GET', 'POST'])
    def webhooks():
        print("in webhooks function\n")
        payload = request.data
        event_json = json.loads(request.data)
        received_sig = request.headers.get('Stripe-Signature', None)
        sig_header = request.headers
        print("Type sig_header:", type(sig_header))
        # print(type(received_sig))
        # print(event_json)
        # print("Received event: id={id}, type={type}".format(id=event_json['id'], type=event_json['type']))
        dec = payload.decode(encoding='UTF-8')

        # TODO : Verification signature a check

        # if stripe.Event.retrieve(event_json['id']) == None:
        #     return 400
        # else:

        # try:
        #     event = stripe.Webhook.construct_event(dec, sig_header, webhook_secret)
        # except ValueError as e:
        #     print(e)
        #     return 'invalid payload', 400
        # except stripe.error.SignatureVerificationError as e:
        #     print(e)
        #     return 'invalid signature', 400

        #  product.created

        #
        # if event_json['type'] == "plan.created":
        #     print("its a plaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaan")
        # else:
        #     print("not a plan")
        # check_event(event_json)

        check_event(event_json)

        return 'got it', 200


def check_event(event_json):

    functions = {
        "plan.created": _plan_created,
        "plan.updated": _plan_updated,
        "plan.deleted": _plan_deleted,
        "product.created": _product_created,
        "product.updated": _product_updated,
        "product.deleted": _product_deleted,
        "customer.subscription.created": _customer_subscription_created,
        "customer.subscription.deleted": _customer_subscription_deleted,
        "invoice.payment_succeeded": _invoice_payment_succeed,
        "charge.succeeded": _charge_succeeded,
        "customer.created": _customer_created,
        "customer.deleted": _customer_deleted,
        "customer.updated": _customer_updated
    }

    if event_json['type'] in functions:
        result = functions[event_json['type']](event_json)
    else:
        print("We currently don\'t manage this event")
        result = None
    return result



from nowhat.plan.models import Plan
# TODO dont forget to remove the comment after integration in the project

def _plan_created(event_json):
    response = Plan.post('/newplan', body=event_json)
    print("Plan created")
    return event_json


def _plan_updated(event_json):
    # response = Plan.put('/updateplan', body=event_json)
    print("plan updated")
    return 200


def _plan_deleted(event_json):
    # response = Plan.delete('/delplan', body=event_json)
    print("plan deleted")
    return 200


def _product_created(event_json):
    # response = Product.post('/newproduct', body=event_json)
    print("product created")
    return 200


def _product_updated(event_json):
    # response = Product.put('/updateproduct', body=event_json)
    print("product updated")
    return 200


def _product_deleted(event_json):
    # response = Product.delete('/delproduct', body=event_json)
    print("product deleted")
    return 200


def _customer_subscription_created(event_json):
    # response = Subscription.put('/createcustomersub', body=event_json)
    print("subscription created for customer")
    return 200


def _customer_subscription_deleted(event_json):
    # response = Product.delete('/delcustonersub', body=event_json) TODO no stripe, out of webhooks
    print("subscription deleted for customer")
    return 200


def _invoice_payment_succeed(event_json):
    # TODO : a voir la deuxieme devrait fonctionner
    # response = Subscription.put('/subscription/event_json['subscription'], body=event_json)
    # response = Subscription.put('/createcustomersub', body=event_json)
    print("invoice payment succeed")
    return 200


# TODO : not sure for now, to do after thinking aout it
def _charge_succeeded(event_json):
    # response = Charge.put('/chargesucceed, body=event_json)
    print("charge payment succeed")
    return 200


def _customer_created(event_json):
    # response = User.put('/newcustomer, body=event_json)
    print("customer created")
    return 200


def _customer_updated(event_json):
    # response = User.put('/updatesourcecustomer, body=event_json) TODO wait and see should be handle out of webhooks
    print("customer succesfully updated")
    return 200


def _customer_deleted(event_json):
    # response = User.put('/deletecustomer, body=event_json) TODO modif user to delete the customer id, out of webhooks
    print("customer deleted")
    return 200


def _create_connected_acc(event_json):
    # response = User.put('/newconnectedacc', body=event_json)
    print("connected account created")


def _update_connected_acc(event_json):
    # response = User.put('/updateconnectedacc', body=event_json)
    print("connected account updated")



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="stripe-Webhook",
    version="0.1.8",
    author="maximeV",
    author_email="vermande.maxime@gmail.com",
    description="a package for stripe webhook",
    # long_description=long_description,
    # long_description_content_type="text/markdown",
    url="https://gitlab.com/maximeV/nowhatstripet",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)